.. py_deps documentation master file, created by
   sphinx-quickstart on Thu Oct 23 23:37:38 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to py_deps's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 2

   README
   basic-usage
   modules/index
   design-notes           

.. toctree::
   :maxdepth: 1
              
   HISTORY

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

